<?php
///----Blog widgets---

/// Recent Posts 
class Bunch_Recent_Post extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Recent_Post', /* Name */esc_html__('Dynamic Recent Posts With Image','dynamic'), array( 'description' => esc_html__('Show the recent posts', 'dynamic' )) );
	}
 

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
        <div class="recent_news_sidebar">
            <?php echo wp_kses_post($before_title.$title.$after_title); ?>
        	
            <?php $query_string = 'posts_per_page='.$instance['number'];
				if( $instance['cat'] ) $query_string .= '&cat='.$instance['cat'];
				query_posts( $query_string ); 
				
				$this->posts();
				wp_reset_query();
            ?>
             
        </div>
        
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ( $instance ) ? esc_attr($instance['title']) : esc_html__('Recent News', 'dynamic');
		$number = ( $instance ) ? esc_attr($instance['number']) : 3;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php esc_html_e('Category', 'dynamic'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'dynamic'), 'selected'=>$cat, 'class'=>'widefat', 'name'=>$this->get_field_name('cat')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts()
	{
		
		if( have_posts() ):?>
        
           	<!-- Title -->
				<?php while( have_posts() ): the_post(); ?>
                
                <div class="single_news_sidebar clear_fix">
                    <div class="img_holder float_left">
                        <?php the_post_thumbnail('75x75');?>
                        <div class="opacity tran3s">
                            <div class="icon">
                                <span><a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="color1_bg"><i class="fa fa-chain s_color" aria-hidden="true"></i></a></span>
                            </div> <!-- End of .icon -->
                        </div> <!-- End of .opacity -->
                    </div> <!-- End of .img_holder -->
            
                    <div class="post float_left">
                        <h6><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><?php echo wp_kses_post(dynamic_trim(get_the_title(), '5'));?></a></h6>
                        <p><a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="tran3s"><i class="fa fa-calendar" aria-hidden="true"></i> <?php echo get_the_date('M d, Y');?></a></p>
                    </div>
                </div>
                <?php endwhile; ?>
            
        <?php endif;
    }
}

/// Testimonial Posts 
class Bunch_Testimonials_Posts extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Testimonials_Posts', /* Name */esc_html__('Dynamic Testimonials Posts','dynamic'), array( 'description' => esc_html__('Show the Testimonials', 'dynamic' )) );
	}
 
	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
		<!-- Sidebar Testimonial -->
		<div class="sidebar_testimonial">
            <?php echo wp_kses_post($before_title.$title.$after_title); ?>
        	
            <?php 
				$args = array('post_type' => 'bunch_testimonials', 'showposts'=>$instance['number']);
				if( $instance['cat'] ) $args['tax_query'] = array(array('taxonomy' => 'testimonials_category','field' => 'id','terms' => (array)$instance['cat']));
				query_posts($args); 
					
					$this->posts();
					wp_reset_query();
			?>
            
        </div>
		
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}
	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ( $instance ) ? esc_attr($instance['title']) : esc_html__('Testimonials', 'dynamic');
		$number = ( $instance ) ? esc_attr($instance['number']) : 3;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php esc_html_e('Category', 'dynamic'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'dynamic'), 'selected'=>$cat, 'taxonomy' => 'services_category', 'class'=>'widefat', 'name'=>$this->get_field_name('cat')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts()
	{	
		$count = 0;
		$data_filtration = array();
   		$data_content = array();
		if( have_posts() ):?>
        
           	<!-- Title -->
				<?php while( have_posts() ): the_post(); 
					$client_meta = _WSH()->get_meta();
	  				$active = ($count == 1) ? 'active' : '';
					
					$data_filtration[get_the_id()] = '<li data-target="#testimonial-Carousel" data-slide-to="'.$count.'" class="'.$active.'"></li>';
					
					$data_content[get_the_id()] = '<div class="item '.$active.'">
														<div class="text">
															<span class="ficon flaticon-quotes"></span>
															<p>'.dynamic_trim(get_the_content(), 18).'</p>
														</div> <!-- End of .text -->
														<span></span>
														<div class="author clear_fix">
															'.get_the_post_thumbnail( get_the_id(), 'thumbnail', array('class' => 'pull-left')).'
															<div class="name pull-left">
																<h5>'.dynamic_set($client_meta, 'designation').' </h5>
																<ul>
																	<li><i class="fa fa-star" aria-hidden="true"></i></li>
																	<li><i class="fa fa-star" aria-hidden="true"></i></li>
																	<li><i class="fa fa-star" aria-hidden="true"></i></li>
																	<li><i class="fa fa-star" aria-hidden="true"></i></li>
																	<li><i class="fa fa-star" aria-hidden="true"></i></li>
																</ul>
															</div> <!-- End of .name -->
														</div> <!-- End of author -->
													</div>';
				?>
				
				<?php $count++; endwhile; ?>
			
        <?php endif;?>
        
        <div id="testimonial-Carousel" class="carousel slide" data-ride="carousel" data-interval="5000">
            <!-- Indicators -->
            <ol class="carousel-indicators">
            <?php foreach($data_filtration as $key => $value):?>
                <?php echo wp_kses_post($value);?>
            <?php endforeach;?>
            </ol>
        
            <!-- Wrapper for slides -->
            <div class="carousel-inner" role="listbox">
            <?php foreach($data_content as $key => $content):?>
                <?php echo wp_kses_post($content);?>
            <?php endforeach;?>
            
            </div>
        </div>
    <?php }
}

//About Us
class Bunch_Business_Enquiry extends WP_Widget
{
	
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Business_Enquiry', /* Name */esc_html__('Dynamic Business Inquiry','dynamic'), array( 'description' => esc_html__('Show the Business Inquiry', 'dynamic' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget);?>
      		
			<!-- Business Enquiry -->
            <div class="business_enquiry">
                <h6><?php echo wp_kses_post($instance['title']); ?></h6>
                <p><?php echo wp_kses_post($instance['content']); ?></p>
                <span class="ficon flaticon-message"></span>
            </div>
            
		<?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['content'] = $new_instance['content'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : 'For Business Enquiry';
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$show = ( $instance ) ? esc_attr($instance['show']) : '';?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('About Us', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('content')); ?>"><?php esc_html_e('Content:', 'dynamic'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>     
                
		<?php 
	}
	
}

///----footer widgets---
//About Us
class Bunch_About_us extends WP_Widget
{
	
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Abous_us', /* Name */esc_html__('Dynamic Abous Us','dynamic'), array( 'description' => esc_html__('Show the information about company', 'dynamic' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		//$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget);?>
      		
			<div class="footer_logo">
                <a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url($instance['logo_url']); ?>" alt="<?php esc_html_e('Logo', 'dynamic');?>"></a>
                <p><?php echo wp_kses_post($instance['content']); ?></p>

                <a href="<?php echo esc_url($instance['req_link']); ?>" class="tran3s"><i class="fa fa-caret-right" aria-hidden="true"></i> <?php esc_html_e('Request Quote', 'dynamic');?></a>
                <a href="<?php echo esc_url($instance['pur_link']); ?>" class="tran3s"><i class="fa fa-caret-right" aria-hidden="true"></i> <?php esc_html_e('Purchase Now', 'dynamic');?></a>
            </div>
            
		<?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['logo_url'] = strip_tags($new_instance['logo_url']);
		$instance['content'] = $new_instance['content'];
		$instance['req_link'] = $new_instance['req_link'];
		$instance['pur_link'] = $new_instance['pur_link'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$logo_url = ($instance) ? esc_attr($instance['logo_url']) : 'http://asianitbd.com/wp/dynamic/wp-content/themes/dynamic/images/logo/logo.png';
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$req_link = ( $instance ) ? esc_attr($instance['req_link']) : '#';
		$pur_link = ( $instance ) ? esc_attr($instance['pur_link']) : '#';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('logo_url')); ?>"><?php esc_html_e('Logo Link:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('Logo Link', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('logo_url')); ?>" name="<?php echo esc_attr($this->get_field_name('logo_url')); ?>" type="text" value="<?php echo esc_attr($logo_url); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('content')); ?>"><?php esc_html_e('Content:', 'dynamic'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>  
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('req_link')); ?>"><?php esc_html_e('Request Link:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('Request Link', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('req_link')); ?>" name="<?php echo esc_attr($this->get_field_name('req_link')); ?>" type="text" value="<?php echo esc_attr($req_link); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('pur_link')); ?>"><?php esc_html_e('Purchase Link:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('Purchase Link', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('pur_link')); ?>" name="<?php echo esc_attr($this->get_field_name('pur_link')); ?>" type="text" value="<?php echo esc_attr($pur_link); ?>" />
        </p>      
                
		<?php 
	}
	
}

/// Recent Posts 
class Bunch_Footer_Latest_News extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Footer_Latest_News', /* Name */esc_html__('Dynamic Footer Latest News','dynamic'), array( 'description' => esc_html__('Show the latest news', 'dynamic' )) );
	}
 

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
        <div class="footer_news">
            <?php echo wp_kses_post($before_title.$title.$after_title); ?>
			
            <?php $query_string = 'posts_per_page='.$instance['number'];
				if( $instance['cat'] ) $query_string .= '&cat='.$instance['cat'];
				query_posts( $query_string ); 
				
				$this->posts();
				wp_reset_query();
            ?>
            
        </div>
        
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ( $instance ) ? esc_attr($instance['title']) : esc_html__('Latest News', 'dynamic');
		$number = ( $instance ) ? esc_attr($instance['number']) : 3;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php esc_html_e('Category', 'dynamic'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'dynamic'), 'selected'=>$cat, 'class'=>'widefat', 'name'=>$this->get_field_name('cat')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts()
	{
		
		if( have_posts() ):?>
        
           	<!-- Title -->
				<ul>
                    <?php while( have_posts() ): the_post(); ?>
                    <li>
                        <span><i class="fa fa-calendar" aria-hidden="true"></i><?php echo get_the_date('M d, Y');?></span>
                        <p><?php echo wp_kses_post(dynamic_trim(get_the_title(), '5'));?></p>
                        <a href="<?php echo esc_url(get_permalink(get_the_id()));?>" class="tran3s"><?php esc_html_e('Read More', 'dynamic');?> <i class="fa fa-caret-right" aria-hidden="true"></i></a>
                    </li>
                    <?php endwhile; ?>
                </ul>
            
        <?php endif;
    }
}

// Subscribe to our mailing list
class Bunch_feedburner extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_subscribe_mail_list', /* Name */esc_html__('Dynamic Subscribe to Mailing List','dynamic'), array( 'description' => esc_html__('create account on http://feedburner.com and allow users to subscribe', 'dynamic' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget);?>
        
        <div class="footer_subscribe">
            <?php echo wp_kses_post($before_title . $title . $after_title) ; ?>
            <p><?php echo wp_kses_post($instance['content']); ?></p>
            <form method="post" id="subscribe" action="http://feedburner.google.com/fb/a/mailverify" accept-charset="utf-8">
                <input type="text" placeholder="<?php esc_html_e('Enter Your Email', 'dynamic')?>">
                <button class="tran3s color1_bg"><i class="fa fa-envelope-o" aria-hidden="true"></i></button>
            </form>
            <span><?php esc_html_e('We never spam!', 'dynamic');?></span>
            <?php if( $instance['show'] ): ?>
            <ul class="social_icon">
                <?php echo wp_kses_post(dynamic_get_social_icons()); ?>
            </ul>
            <?php endif; ?>
        </div>
		
		<?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['content'] = $new_instance['content'];
		$instance['ID'] = $new_instance['ID'];
		$instance['show'] = $new_instance['show'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : esc_html__('Subscribe Newsletter', 'dynamic');
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$ID = ($instance) ? esc_attr($instance['ID']) : 'themeforest';
		$show = ( $instance ) ? esc_attr($instance['show']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('content')); ?>"><?php esc_html_e('Content:', 'dynamic'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('ID')); ?>"><?php esc_html_e('Feedburner ID:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('ID')); ?>" name="<?php echo esc_attr($this->get_field_name('ID')); ?>" type="text" value="<?php echo esc_attr($ID); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('show')); ?>"><?php esc_html_e('Show Social Icons:', 'dynamic'); ?></label>
			<?php $selected = ( $show ) ? ' checked="checked"' : ''; ?>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('show')); ?>"<?php echo esc_attr($selected); ?> name="<?php echo esc_attr($this->get_field_name('show')); ?>" type="checkbox" value="true" />
        </p>
		<?php 
	}
}

//About Us
class Bunch_Contact_Carousel extends WP_Widget
{
	
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Contact_Carousel', /* Name */esc_html__('Dynamic Contact Info','dynamic'), array( 'description' => esc_html__('Show the Contact information', 'dynamic' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget);?>
      		
			<div class="footer_contact">
                <?php echo wp_kses_post($before_title.$title.$after_title); ?>>
                <div class="item">
                    <h6><?php echo wp_kses_post($instance['sub_title']); ?></h6>
                    <ul>
                        <li><span class="ficon flaticon-map"></span> <?php echo wp_kses_post($instance['address']); ?></li>
                        <li><span class="ficon flaticon-mobile"></span> <?php esc_html_e('Call us : ', 'dynamic');?> <?php echo wp_kses_post($instance['phone']); ?></li>
                        <li><span class="ficon flaticon-message"></span> <?php esc_html_e('Mail us : ', 'dynamic');?> <?php echo wp_kses_post($instance['email']); ?></li>
                        <li><span class="ficon flaticon-clock"></span> <?php echo wp_kses_post($instance['schdule']); ?>,<br><?php esc_html_e('Sunday CLOSED', 'dynamic');?></li>
                    </ul>
                </div>
            </div>
            
		<?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['sub_title'] = $new_instance['sub_title'];
		$instance['address'] = $new_instance['address'];
		$instance['phone'] = $new_instance['phone'];
		$instance['email'] = $new_instance['email'];
		$instance['schdule'] = $new_instance['schdule'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : 'Contact Details';
		$sub_title = ($instance) ? esc_attr($instance['sub_title']) : 'California Office';
		$address = ($instance) ? esc_attr($instance['address']) : '007 Edgar Buildings,<br>George Street, CA 03, USA';
		$phone = ($instance) ? esc_attr($instance['phone']) : '+3257 700 1430';
		$email = ( $instance ) ? esc_attr($instance['email']) : 'USA@Consulting.com';
		$schdule = ( $instance ) ? esc_attr($instance['schdule']) : 'Mon - Sat 9.00 - 20.00';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('title', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('sub_title')); ?>"><?php esc_html_e('Sub Title:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('sub title', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('sub_title')); ?>" name="<?php echo esc_attr($this->get_field_name('sub_title')); ?>" type="text" value="<?php echo esc_attr($sub_title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')); ?>"><?php esc_html_e('Address:', 'dynamic'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" ><?php echo wp_kses_post($address); ?></textarea>
        </p>  
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>"><?php esc_html_e('Phone', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('phone', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" type="text" value="<?php echo esc_attr($phone); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email')); ?>"><?php esc_html_e('Email', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('email', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" type="text" value="<?php echo esc_attr($email); ?>" />
        </p>  
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('schdule')); ?>"><?php esc_html_e('Opening Schdule:', 'dynamic'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('schdule')); ?>" name="<?php echo esc_attr($this->get_field_name('schdule')); ?>" ><?php echo wp_kses_post($schdule); ?></textarea>
        </p>    
                
		<?php 
	}
	
}

/// External Pages
class Bunch_External_Links extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_External_Links', /* Name */esc_html__('Dynamic External Pages','dynamic'), array( 'description' => esc_html__('Show the external Pages', 'dynamic' )) );
	}
 
	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
		<!--Sidebar Widget / Styled Nav-->
        <ul class="page_list">
        	<?php 
				$args = array('post_type' => 'bunch_services', 'showposts'=>$instance['number']);
				if( $instance['cat'] ) $args['tax_query'] = array(array('taxonomy' => 'services_category','field' => 'id','terms' => (array)$instance['cat']));
				query_posts($args); 
					
					$this->posts();
					wp_reset_query();
			?>
        </ul>
		 
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}
	/** @see WP_Widget::form */
	function form($instance)
	{
		$number = ( $instance ) ? esc_attr($instance['number']) : 7;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php esc_html_e('Category', 'dynamic'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'dynamic'), 'selected'=>$cat, 'taxonomy' => 'services_category', 'class'=>'widefat', 'name'=>$this->get_field_name('cat')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts()
	{
		
		if( have_posts() ):?>
        
           	<?php while( have_posts() ): the_post();
			$services_meta = _WSH()->get_meta();
			 ?>
				<li><a href="<?php echo esc_url(dynamic_set($services_meta, 'ext_url'));?>" class="tran3s"><?php the_title();?></a></li>
			<?php endwhile; ?>            
                
        <?php endif;
    }
}

//About Us
class Bunch_PDF_Broucher extends WP_Widget
{
	
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_PDF_Broucher', /* Name */esc_html__('Dynamic PDF Brouchers','dynamic'), array( 'description' => esc_html__('Show the PDF', 'dynamic' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget);?>
      		
			<!-- Our Brochures -->
            <div class="our_brochures">
                <?php echo wp_kses_post($before_title.$title.$after_title); ?>
                <a href="<?php echo esc_url($instance['pdf_link']); ?>" class="tran3s color1_bg wow fadeInUp"><span class="color2_bg tran3s"><i class="fa fa-file-pdf-o" aria-hidden="true"></i></span><?php esc_html_e('Download.Pdf', 'dynamic');?></a>
                <a href="<?php echo esc_url($instance['doc_link']); ?>" class="tran3s color1_bg wow fadeInUp"><span class="color2_bg tran3s"><i class="fa fa-file-word-o" aria-hidden="true"></i></span><?php esc_html_e('Download.Doc', 'dynamic');?></a>
            </div>
            
		<?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = strip_tags($new_instance['title']);
		$instance['pdf_link'] = $new_instance['pdf_link'];
		$instance['doc_link'] = $new_instance['doc_link'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : 'Our Brochures';
		$pdf_link = ( $instance ) ? esc_attr($instance['pdf_link']) : '#';
		$doc_link = ( $instance ) ? esc_attr($instance['doc_link']) : '#';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('title here', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('pdf_link')); ?>"><?php esc_html_e('PDF Link:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('PDF Link', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('pdf_link')); ?>" name="<?php echo esc_attr($this->get_field_name('pdf_link')); ?>" type="text" value="<?php echo esc_attr($pdf_link); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('doc_link')); ?>"><?php esc_html_e('PDF Link:', 'dynamic'); ?></label>
            <input placeholder="<?php esc_html_e('PDF Link', 'dynamic');?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('doc_link')); ?>" name="<?php echo esc_attr($this->get_field_name('doc_link')); ?>" type="text" value="<?php echo esc_attr($doc_link); ?>" />
        </p>      
                
		<?php 
	}
	
}

/// footer Gallery Posts 
class Bunch_Footer_Gallery_Post extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Bunch_Footer_Gallery_Post', /* Name */esc_html__('Dynamic Footer Gallery Post','dynamic'), array( 'description' => esc_html__('Show the gallery Posts', 'dynamic' )) );
	}
 
	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
        <div class="sidebar_recent_project wow fadeInUp">
            <?php echo wp_kses_post($before_title.$title.$after_title); ?>
            <?php $query_string = 'posts_per_page='.$instance['number'];
				if( $instance['cat'] ) $query_string .= '&cat='.$instance['cat'];
				query_posts( $query_string ); 
				
				$this->posts();
				wp_reset_query();
			?>
            
        </div>
		 
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}
	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ( $instance ) ? esc_attr($instance['title']) : esc_html__('Recent Projects', 'dynamic');
		$number = ( $instance ) ? esc_attr($instance['number']) : 9;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
		    <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'dynamic'); ?></label>
		    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'dynamic'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php esc_html_e('Category', 'dynamic'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'dynamic'), 'selected'=>$cat, 'class'=>'widefat', 'name'=>$this->get_field_name('cat')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts()
	{
		
		if( have_posts() ):?>
        	
            <div class="row">
                <?php while( have_posts() ): the_post(); ?>
                <?php 
                    $post_thumbnail_id = get_post_thumbnail_id($post->ID);
                    $post_thumbnail_url = wp_get_attachment_url( $post_thumbnail_id );
                ?>
                <div class="col-lg-4 col-md-4 col-sm-2 col-xs-2">
                    <div class="img_holder">
                        <?php the_post_thumbnail('dynamic_84x83', array('class' => 'img-responsive'));?>
                        <div class="overlay tran3s"><a href="<?php echo esc_url(get_permalink(get_the_id()));?>"><span><i class="fa fa-chain" aria-hidden="true"></i></span></a></div>
                    </div> <!-- End of .img_holder -->
                </div>
                <?php endwhile; ?>
            </div>
            
        <?php endif;
    }
}